#!/bin/bash


LOG_TO_FILE="/opt/assistant/log/cert.log"
PATHS_TO_CERT=(
"/etc/ssl/certs/ca-certificates.crt" 
"/etc/pki/tls/certs/ca-bundle.crt" 
"/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem" 
"/usr/share/ca-certificates/ca-bundle.crt" 
"/etc/ssl/certs/ssl-cert-snakeoil.pem" 
"/etc/ca-certificates/extracted/ca-bundle.trust.crt"
)

{
	echo "--------------------------------------------------------------------"
	date
} >> $LOG_TO_FILE
echo "Start Assistant cert script" >> $LOG_TO_FILE

if [ -f /etc/os-release ]; then
    . /etc/os-release
fi

ID=$(echo "$ID" | sed -r 's/\"//g')
VER=$(echo "$VERSION_ID" | sed -r 's/\"//g')

mkdir -p /etc/assistant/cert/
CERT_PATH=/etc/assistant/cert/ca-cert-native

make_ca()
{
for cert in ${PATHS_TO_CERT[@]}
	do
		if [ -f $cert ] && [ ! -L $cert ]; then 
		# echo "Сертификат: "$cert 
		ln -s $cert $CERT_PATH
		echo "CA "\"$cert\""  selected" >> $LOG_TO_FILE 
		return 0;
		fi
	done
	echo "Unsupported version $ID $VER" | tee -a $LOG_TO_FILE 
	return 1
}


case $1 in 
	"--install" | "-i")
		[ -L $CERT_PATH ] || ( make_ca && echo "CA installed." | tee -a $LOG_TO_FILE )
	;;
	"--uninstall" | "-u")
		[ ! -L $CERT_PATH ] || ( rm -r /etc/assistant && echo "CA deleted." | tee -a $LOG_TO_FILE )
	;;
	*)
		echo "Invalid params: "\"$*\" | tee -a $LOG_TO_FILE
	;;
esac

echo -e "Assistant CA script setup complete\n" >> $LOG_TO_FILE

exit 0