#!/bin/bash
LOG_TO_FILE=/opt/assistant/log/daemon.log

echo "Start Assistant daemon setup script"

INST_DIR="/opt/assistant"
. $INST_DIR/scripts/get_version_os.sh

if [ -L /sbin/init ]
then
    SYS=$(readlink /sbin/init | sed -r 's/.*\///')
else
    SYS="init"
fi

if [[ $ID == "calculate" ]]
then
    SYS="openrc"
fi

echo "Found $SYS initialization system"

#
# check root sudo entry
#

SUDO_MAIN_PATTERN="#includedir /etc/sudoers.d"
SUDO_MAIN_REGEXP_PATTERN="#includedir \/etc\/sudoers.d"
SUDO_MAIN_FILE="/etc/sudoers"

SUDO_PATTERN="root ALL=(ALL) /opt/assistant/bin/"
SUDO_PATTERN_SCRIPTS="root ALL=(ALL) /opt/assistant/scripts/"
SUDO_PATTERN_SETCAP="root ALL=(ALL) /sbin/setcap"

SUDO_OLD_REGEXP_PATTERN="root ALL=(ALL) \/opt\/assistant\/bin\/assistant"
SUDO_FILE="/etc/sudoers.d/assistant"


add_sudo_entry(){
	# add sudo dir
    if grep -q "$SUDO_MAIN_REGEXP_PATTERN" $SUDO_MAIN_FILE
    then 
        echo "Sudo main entry already exist" >> $LOG_TO_FILE
        echo "Запись sudo main entry существует"
    else
        echo "Добавляем запись sudo main entry"
        echo "Adding sudo amin entry" >> $LOG_TO_FILE
        echo "$SUDO_MAIN_PATTERN" >> $SUDO_MAIN_FILE
    fi
    # create /etc/sudoers.d/assistant
    if ! [ -d /etc/sudoers.d ]
    then
        mkdir /etc/sudoers.d
    fi
    echo "$SUDO_PATTERN" > $SUDO_FILE
    echo "$SUDO_PATTERN_SCRIPTS" >> $SUDO_FILE
    echo "$SUDO_PATTERN_SETCAP" >> $SUDO_FILE
    # echo "$SUDO_PATTERN_M" >> $SUDO_FILE
    # echo "$SUDO_PATTERN_S" >> $SUDO_FILE

    # remove old sudo task
    if grep -q "$SUDO_OLD_REGEXP_PATTERN" $SUDO_MAIN_FILE
    then
        echo "Removing old sudo entry" >> $LOG_TO_FILE
        echo "Удаление записи sudo "
		sed -i "/${SUDO_OLD_REGEXP_PATTERN}/d" $SUDO_MAIN_FILE

        # sed -i "/root ALL=(ALL) \/opt\/assistant\/bin\/assistant/d" $SUDO_MAIN_FILE
    fi
    
    chmod 0400 $SUDO_FILE
}


remove_sudo(){
    echo "Remove sudo file" >> $LOG_TO_FILE
    echo "Удаляем запись sudo"
    rm -f $SUDO_FILE
}


#
# create service
#

case "${ID}" in
	"calculate"|"gentoo")
		case $1 in
		"--install" | "-i")
			add_sudo_entry
			echo "Calculate linux detected, run openRC setup"
			rc-update delete zassistantd
			eselect rc stop zassistantd
			cp /opt/assistant/scripts/openrc.s /etc/init.d/zassistantd
			cp /opt/assistant/scripts/openrc.t /opt/assistant/scripts/runasts.sh 
			cp /opt/assistant/scripts/ast_restart.t /opt/assistant/scripts/ast_restart.sh
					cp /opt/assistant/scripts/assistant.desktop /usr/share/applications/
			chmod +x /etc/init.d/zassistantd

			echo "Files copied"

			/sbin/rc-update add zassistantd default
			/sbin/rc-service zassistantd start

			echo "Service runned"
			#
			# create cron task
			#
			CRON_PATTERN="*/1 * * * * root /opt/assistant/scripts/ast_restart.sh"
			CRON_REGEXP_PATTERN="^\*\/1 \* \* \* \* root \/opt\/assistant\/scripts\/ast_restart\.sh$"
			CRON_FILE="/etc/crontab"

			if grep -q "$CRON_REGEXP_PATTERN" $CRON_FILE
			then 
				echo "Crontab entry already exist" >> $LOG_TO_FILE
				echo "Crontab entry already exist"
			else
				echo "Adding crontab entry" >> $LOG_TO_FILE
				echo "Adding crontab entry"
				echo "$CRON_PATTERN" >> $CRON_FILE
			fi

			echo "Cron task created"
		;;
		"--uninstall" | "-u")
			remove_sudo
			CRON_PATTERN="*/1 * * * * root /opt/assistant/scripts/ast_restart.sh"
			CRON_REGEXP_PATTERN="^\*\/1 \* \* \* \* root \/opt\/assistant\/scripts\/ast_restart\.sh$"
			CRON_FILE="/etc/crontab"
				# remove old cron task
				if grep -q "$CRON_REGEXP_PATTERN" $CRON_FILE
				then
					echo "Removing old cron entry" 
					sed -i "/${CRON_REGEXP_PATTERN}/d" $CRON_FILE
				fi
			rc-update delete zassistantd
			eselect rc stop zassistantd
			killall assistant 2> /dev/null
			killall asts 2> /dev/null
			killall master 2> /dev/null
			killall slave 2> /dev/null
		;;
		*)
			echo "Invalid params: "\"$*\"
		;;
		esac
	;;
        *)
		case $1 in 
		"--install" | "-i")
			add_sudo_entry
			cp /opt/assistant/scripts/assistant.service /lib/systemd/system/assistant.service
			systemctl enable assistant.service
			systemctl start assistant.service
		;;
		"--uninstall" | "-u")
			remove_sudo
			systemctl stop assistant.service
			systemctl disable  assistant.service
		;;
		*)
			echo "Invalid params: "\"$*\"
		;;
		esac
	;;
esac

exit 0
